
# Bing for Commerce Search Python SDK

This contains the generated SDKs that can help developers integrate with Bing for Commerce search APIs.

For help, or more details about the project, please refer to:

* [Bing for Commerce Python SDK github repository](https://github.com/microsoft/bing-commerce-sdk-for-python)
* [Bing for Commerce central repository](https://github.com/microsoft/bing-commerce)
* [Bing for Commerce API Documentation](https://commerce.bing.com/docs/product-search/)